package industries.sunshine.planningpoker

import scala.scalajs.js
import com.raquo.laminar.api.L.{*, given}

/** Rendering of the Room state
  */
object RoomView {
  // TODO this will take in signal of the room observable
  // NOTE i guess "other players" would have to be in circle with 'me' as empty space in the bottom
  def renderRoom(state: RoomStateView): Element = {
    val roomStateSignal = Var(state).signal
    val otherPlayers = roomStateSignal.map { state =>
      state.players.filterNot(_.id == state.me)
    }

    div(
      className := "w-96 h-96 border-4 border-amber-900",
      div(
        className := "flex flex-row",
        children <-- otherPlayers.split(_.id) { (id, initial, playerSignal) =>
            renderPlayer(playerSignal, roomStateSignal.map(_.allowedCards.size))
        }
      )
    )
  }

  def renderPlayer(p: Signal[Player], cardsAmount: Signal[Int]): Element = {
    div(
      className := "w-20 h-20 border-2 border-amber-400 m-2",
      child.text <-- p.map(_.name),
      renderHandCardBacks(cardsAmount)
    )
  }

  // TODO will also be a signal, i suppose separate, yeah
  def renderHandCardBacks(amountSignal: Signal[Int]): Element = {
    def renderCard(index: Int): Element =
      div(
        className := "w-4 h-8 m-1 rounded bg-gray-600 text-yellow-400"
      )

    div(
      className := "flex flex-row",
      children <-- amountSignal.map { amount => (1 to amount).map(renderCard) }
    )
  }
}
